if not Skada then return end

local s = Skada
local AddonName, a = ...
local L = a.Localize
local sL = LibStub("AceLocale-3.0"):GetLocale("Skada", false)

local function nameMatches(longName, shortName)
    if #longName > #shortName then
        shortName = shortName .. "-"
        longName = string.sub(longName, 1, string.len(shortName))
    end
    return longName == shortName
end

function setBarInfo(index, info, healing, win, set)
    local d = win.dataset[index] or {}
    win.dataset[index] = d
    d.id = info.id
    d.label = info.name
    d.value = healing
    d.activetime = s:PlayerActiveTime(set, info)
    d.class = info.class
    
    win.metadata.maxvalue = math.max(win.metadata.maxvalue, healing)
end

function setBarText(win, numBars, total, columnFlags)
    for i = 1, numBars do
        local d = win.dataset[i]
        d.valuetext = s:FormatValueText(
            s:FormatNumber(d.value),
            columnFlags.Healing,
            string.format(
                "%02.1f", d.value / math.max(1, d.activetime)),
            columnFlags.HPS,
            string.format(
                "%02.1f%%", d.value / total * 100),
            columnFlags.Percent)
    end
end

--------------------------------------------------------- Healing Taken Submenu
local healingTakenSubmenu = s:NewModule(L["Healing Taken"])

healingTakenSubmenu.metadata = {
    showspots = true,
    columns = { Healing = true, HPS = true, Percent = true }
}

function healingTakenSubmenu:Enter(win, id, label)
    self.playerid = id
    self.title = L["Healing Taken"] .. ": " .. label
end

function healingTakenSubmenu:Update(win, set)
    local targetName = s:find_player(set, self.playerid).name
    local numBars = 0
    local total = 0
    
    win.metadata.maxvalue = 0
    for _, sourceInfo in pairs(set.players) do
        local healing = 0
        for candidateTargetName, heal in pairs(sourceInfo.healed) do
            if nameMatches(candidateTargetName, targetName) then
                healing = healing + heal.amount
            end
        end
        if healing > 0 then
            numBars = numBars + 1
            setBarInfo(numBars, sourceInfo, healing, win, set)
            total = total + healing
        end
    end
    setBarText(win, numBars, total, self.metadata.columns)
end

--------------------------------------------------------- Healing Required Mode
local healingRequiredMode = s:NewModule(L["Healing Required"])

healingRequiredMode.metadata = {
    showspots = true,
    click1 = healingTakenSubmenu,
    columns = { Healing = true, HPS = true, Percent = true }
}

function healingRequiredMode:Update(win, set)    
    local numBars = 0
    local total = 0
    
    win.metadata.maxvalue = 0
    for _, targetInfo in pairs(set.players) do
        local targetName = targetInfo.name
        local healing = 0
        for _, sourceInfo in pairs(set.players) do
            if sourceInfo.name ~= targetName then
                for candidateTargetName, heal in pairs(sourceInfo.healed) do
                    if nameMatches(candidateTargetName, targetName) then
                        healing = healing + heal.amount
                    end
                end
            end
        end
        if healing > 0 then
            numBars = numBars + 1
            setBarInfo(numBars, targetInfo, healing, win, set)
            total = total + healing
        end
    end
    setBarText(win, numBars, total, self.metadata.columns)
end

s:AddMode(healingRequiredMode)